# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.bgp_api import BGPApi  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestBGPApi(object):
    """BGPApi unit test stubs"""

    def test_delete_ipsec_endpoint_bgp_peer(self):
        """Test case for delete_ipsec_endpoint_bgp_peer

        """
        pass

    def test_post_create_ipsec_endpoint_bgp_peer(self):
        """Test case for post_create_ipsec_endpoint_bgp_peer

        """
        pass

    def test_put_edit_ipsec_endpoint_bgp_peer(self):
        """Test case for put_edit_ipsec_endpoint_bgp_peer

        """
        pass
